@@ -8,7 +8,7 @@ use FFI::Platypus::Function;
 use FFI::Platypus::Type;
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '0.99_02'; # TRIAL VERSION
+our $VERSION = '0.99_03'; # TRIAL VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -525,7 +525,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 0.99_02
+version 0.99_03
 
 =head1 SYNOPSIS
 
@@ -1886,6 +1886,35 @@ is identical to the process of defining macro constants in Perl.
 
 For more details on enumerated types see L<FFI::Platypus::Type/"Enum types">.
 
+=head2 Memory leaks
+
+There are a couple places where memory is allocated, but never deallocated that may
+look like memory leaks by tools designed to find memory leaks like valgrind.  This
+memory is intended to be used for the lifetime of the perl process so there normally
+this isn't a problem unless you are embedding a Perl interpreter which doesn't closely
+match the lifetime of your overall application.
+
+Specifically:
+
+=over 4
+
+=item type cache
+
+some types are cached and not freed.  These are needed as long as there are FFI
+functions that could be called.
+
+=item attached functions
+
+Attaching a function as an xsub will definitely allocate memory that won't be freed
+because the xsub could be called at any time, including in C<END> blocks.
+
+=back
+
+The Platypus team plans on adding a hook to free some of this "leaked" memory
+for use cases where Perl and Platypus are embedded in a larger application
+where the lifetime of the Perl process is significantly smaller than the
+overall lifetime of the whole process.
+
 =head2 I get seg faults on some platforms but not others with a library using pthreads.
 
 On some platforms, Perl isn't linked with C<libpthreads> if Perl threads are not
